@@ -1,6 +1,8 @@
 #include <cmath>
 #include "NewtonRp.h"
 
+using namespace std;
+
 namespace newtonrp  {
 
 double lsrch(double x0,double (*f)(double),double (*f1)(double),double (*f2)(double),double lb,double ub,double precision)
@@ -20,7 +22,7 @@ double lsrch(double x0,double (*f)(double),double (*f1)(double),double (*f2)(dou
 		else dlt = y*dy/dy2;
 		do {
 			x1 = x - dlt;
-			if ( x < lb || x > ub || ( e = fabs((y1=f(x1))) ) >= e0) dlt /= 2;
+			if ( x < lb || x > ub || ( e = std::fabs((y1=f(x1))) ) >= e0) dlt /= 2;
 		} while (e >= e0);
 		x = x1;
 		y = y1;
